@@ -21,8 +21,8 @@ from aiida_gromacs.utils import searchprevious
 INPUT_DIR = os.path.join(os.getcwd())
 profile = load_profile()
 computer = helpers.get_computer()
-code = helpers.get_code(entry_point="gromacs", computer=computer)
-code = helpers.get_code(entry_point="bash", computer=computer)
+# code = helpers.get_code(entry_point="gromacs", computer=computer)
+# code = helpers.get_code(entry_point="bash", computer=computer)
 
 
 def launch_genericMD(options):
@@ -157,4 +157,4 @@ def cli(**kwargs):
 
 
 if __name__ == "__main__":
-    cli()  # pylint: disable=no-value-for-parameter
+    cli()  # pylint: disable=no-value-for-parameter
\ No newline at end of file
