@@ -5,7 +5,7 @@ pytest_plugins = ["aiida.manage.tests.pytest_fixtures"]
 
 
 @pytest.fixture(scope="function", autouse=True)
-def clear_database_auto(clear_database):  # pylint: disable=unused-argument
+def clear_database_auto(aiida_profile_clean):  # pylint: disable=unused-argument
     """Automatically clear database in between tests."""
 
 
